#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Mar  3 16:47:40 2021

@author: anton
"""

from SLiCAP import *

prj = initProject('Noisy Voltage Amplifier')

files = ['noisyVamp', 'noisyVampSimple']

noiseFigures = []

for fileName in files:

    makeNetlist(fileName + '.asc', fileName)
    i1 = instruction()
    i1.setCircuit(fileName + '.cir')
    i1.setSimType('symbolic')
    i1.setGainType('vi')
    i1.setDataType('noise')
    i1.setDetector('V_out')
    i1.setSource('V1')
    noiseResult = i1.execute()
    
    htmlPage('Noise Analysis')
    head2html('Circuit diagram')
    img2html(fileName + '.svg', 600, label = 'fig_' + fileName, caption = 'Schematics of ' + fileName + '.')
    noise2html(noiseResult)
    
    # Print the noise figure
    F  = noiseResult.inoise/noiseResult.inoiseTerms['V1']
    NF = 10*sp.log(F)/sp.log(10)
    noiseFigures.append(F)

ini.htmlIndex = 'index.html'
htmlPage('Noise figures')
head2html(files[0])
eqn2html('F', noiseFigures[0])
head2html(files[1])
eqn2html('F', noiseFigures[1])
head2html('Comparison')
Fdifference = sp.simplify(noiseFigures[0] - noiseFigures[1])
if sp.simplify(Fdifference) == 0:
    text2html('Both models have the same noise figure:')
else:
    text2html('Difference found between the noise figures obtained with the two models:')
    
eqn2html('F_' + files[0] + ' - F_' + files[1], Fdifference)